==> flutter_slick-3.4.7.tar.gz: lib/components/fields/email.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_slick/navigation/logic.dart';
import 'package:flutter_slick/utils/validators.dart';
import 'package:provider/provider.dart';

class EmailField extends StatefulWidget {
  final String? initialValue;
  final FieldValidator<String>? validator;
  final bool? enabled;
  final String labelText;
  final FocusNode? focusNode;
  final TextEditingController? controller;
  final bool autofocus;
  final void Function(String?) onChanged;
  final ValueChanged<String>? onFieldSubmitted;

  const EmailField({
    super.key,
    this.initialValue,
    this.validator,
    this.enabled,
    this.onFieldSubmitted,
    this.focusNode,
    this.controller,
    this.autofocus = false,
    required this.labelText,
    required this.onChanged,
  });

  @override
  State<EmailField> createState() => _EmailFieldState();
}

class _EmailFieldState extends State<EmailField> {
  late TextEditingController controller;

  @override
  void initState() {
    super.initState();
    controller = widget.controller ?? TextEditingController();
    controller.addListener(() {
      if (controller.text != widget.initialValue) {
        Provider.of<NavigationLogic>(context, listen: false).setDirty();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    var validator = widget.validator;
    return TextFormField(
      enabled: widget.enabled,
      initialValue: widget.initialValue,
      controller: controller,
      onChanged: widget.onChanged,
      validator: CombinedFieldValidator<String>([
        EmailFieldValidator(),
        if (validator != null) validator,
      ]),
      autofocus: widget.autofocus,
      keyboardType: TextInputType.emailAddress,
      decoration: InputDecoration(
        labelText: widget.labelText,
      ),
      onFieldSubmitted: widget.onFieldSubmitted,
      autofillHints: const [
        AutofillHints.username,
        AutofillHints.email,
      ],
      focusNode: widget.focusNode,
    );
  }
}

==> flutter_slick-3.4.13.tar.gz: lib/components/fields/email.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_slick/navigation/logic.dart';
import 'package:flutter_slick/utils/validators.dart';
import 'package:provider/provider.dart';

class EmailField extends StatefulWidget {
  final String? initialValue;
  final FieldValidator<String>? validator;
  final bool? enabled;
  final String labelText;
  final FocusNode? focusNode;
  final TextEditingController? controller;
  final bool autofocus;
  final void Function(String?) onChanged;
  final ValueChanged<String>? onFieldSubmitted;

  const EmailField({
    super.key,
    this.initialValue,
    this.validator,
    this.enabled,
    this.onFieldSubmitted,
    this.focusNode,
    this.controller,
    this.autofocus = false,
    required this.labelText,
    required this.onChanged,
  });

  @override
  State<EmailField> createState() => _EmailFieldState();
}

class _EmailFieldState extends State<EmailField> {
  String? _currentValue;
  late FocusNode focusNode;

  @override
  void initState() {
    super.initState();

    _currentValue = widget.initialValue;
    focusNode = widget.focusNode ?? FocusNode();
    focusNode.addListener(() {
      if (focusNode.hasFocus) return;
      if (_currentValue != widget.initialValue) {
        Provider.of<NavigationLogic>(context, listen: false).setDirty();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    var validator = widget.validator;
    return TextFormField(
      enabled: widget.enabled,
      initialValue: widget.initialValue,
      controller: widget.controller,
      onChanged: (value) {
        _currentValue = value;
        widget.onChanged(value);
      },
      validator: CombinedFieldValidator<String>([
        EmailFieldValidator(),
        if (validator != null) validator,
      ]),
      autofocus: widget.autofocus,
      keyboardType: TextInputType.emailAddress,
      decoration: InputDecoration(
        labelText: widget.labelText,
      ),
      onFieldSubmitted: widget.onFieldSubmitted,
      autofillHints: const [
        AutofillHints.username,
        AutofillHints.email,
      ],
      focusNode: focusNode,
    );
  }
}
